@@ -1,5 +1,5 @@
 from Qt import QtGui, QtCore, QtWidgets
-
+import sys
 
 class NumberBar(QtWidgets.QWidget):
     def __init__(self, edit):
@@ -12,7 +12,7 @@ class NumberBar(QtWidgets.QWidget):
         QtWidgets.QWidget.paintEvent(self, event)
 
     def adjustWidth(self, count):
-        width = self.edit.fontMetrics().width(unicode(count))
+        width = self.edit.fontMetrics().width(str(count))
         if self.width() != width:
             self.setFixedWidth(width)
 
@@ -206,7 +206,7 @@ class CompletionTextEdit(QtWidgets.QPlainTextEdit):
                 pen.setColor(QtGui.QColor("#5B5B5B"))
                 painter.setPen(pen)
             paint_rect = QtCore.QRect(0, block_top+2, number_bar.width(), font_metrics.height())
-            painter.drawText(paint_rect, QtCore.Qt.AlignRight, unicode(line_count))
+            painter.drawText(paint_rect, QtCore.Qt.AlignRight, str(line_count))
             block = block.next()
         painter.end()
 
@@ -352,7 +352,8 @@ class CompletionTextEdit(QtWidgets.QPlainTextEdit):
         while pos > 0:
             pos -= 1
             char = self.document().toPlainText()[pos]
-            char = char.encode('utf-8')
+            if sys.version_info[0] < 3:
+                char = char.encode('utf-8')
             eow = "~!@#$%^&*()_+{}|:<>?,/;'\n[]\\= "  # end of word
             if char in eow:
                 break
@@ -424,7 +425,7 @@ class CompletionTextEdit(QtWidgets.QPlainTextEdit):
 
         if not isShortcut:
             hasModifier = event.modifiers() in (QtCore.Qt.ControlModifier, QtCore.Qt.AltModifier)
-            if hasModifier or event.text().encode('utf-8') == '' or len(completionPrefix) < 3 or event.text().encode('utf-8')[-1] in eow:
+            if hasModifier or event.text() == '' or len(completionPrefix) < 3 or event.text()[-1] in eow:
                 if self.completer:
                     self.completer.popup().hide()
                     return
@@ -488,7 +489,7 @@ class Highlighter(QtGui.QSyntaxHighlighter):
 
         w = list(words)
         ops = ['\+', '\*', '\/', '\%', '\-', '\=', '\!\=', '\<', '\>', '\<\=', '\>\=']
-        vals = ['True', 'False', 'None']
+        vals = ['True', 'False', 'None', 'self']
         keywordPatterns = ["\\b%s\\b" % x for x in w]
         opsPatterns = ["%s" % x for x in ops]
         valPatterns = ["%s" % x for x in vals]
