@@ -3,10 +3,13 @@ import uuid
 import json
 import sys
 import os
-from six import string_types
 from pymongo import MongoClient
 
 
+def isString(var):
+    return isinstance(var, str if sys.version_info[0] >= 3 else basestring)
+
+
 def connect(name=None, user=None, pwd=None):
     """Called at mangrove startup and used to set up global variables to access to the database.
     In this case the variable db, which stores the mongo connection."""
@@ -28,14 +31,14 @@ def connect(name=None, user=None, pwd=None):
 
 def toHtml(s):
     """Convert string to html formatting."""
-    if isinstance(s, string_types):
+    if isString(s):
         return s.replace('"', '&quot;').replace("'", '&apos;').replace("\\", "&#92;")
     return s
 
 
 def fromHtml(s):
     """Convert string from html formatting."""
-    if isinstance(s, string_types):
+    if isString(s):
         return s.replace('&quot;', '"').replace('&apos;', "'").replace("&#92;", "\\")
     return s
 
@@ -171,7 +174,7 @@ def getBatchScript(project_name, name=None, uuid=None):
     if name:
         gt = db[project_name].find_one({'code': 'BatchScript', 'parent': pid, 'name': name})
 
-    node_type = mgvApi.MgvBatchScript(uuid=gt['_id'], name=gt['name'], users=gt['users'],
+    node_type = mgvApi.MgvBatchScript(uuid=gt['_id'], name=gt['name'], users=gt['users'], menu=gt['menu'],
                                       script=gt['script'], pattern=gt['pattern'], template=gt['template'])
     return node_type
 
@@ -258,12 +261,13 @@ def getProject(project_name):
         for gn in db[project_name].find({'code': 'BatchScript', 'parent': pid}):
             batid = gn['_id']
             batname = gn['name']
+            batmenu = gn['menu'] if 'menu' in gn else ''
             batscript = gn['script']
             batusers = gn['users']
             batpattern = gn['pattern']
             battemplate = gn['template']
             pypbatch = mgvApi.MgvBatchScript(uuid=batid, name=batname, script=batscript, users=batusers,
-                                             pattern=batpattern, template=battemplate)
+                                             pattern=batpattern, template=battemplate, menu=batmenu)
             batchs.append(pypbatch)
         huds = []
         for gn in db[project_name].find({'code': 'Hud', 'parent': pid}):
@@ -303,7 +307,7 @@ def getProject(project_name):
 
 def getProjectNames():
     """Returns the list of the projects's names."""
-    return db.list_collection_names()
+    return list(db.list_collection_names())
 
 
 def getPatternGraphs(pattern, with_node_named=None, with_type_named=None):
@@ -357,7 +361,7 @@ def getGraphInfo(pattern, keys):
                                       {'template_name': 1})
         return {'code': 'Graph', 'uuid': g['_id'], 'template_name': g['template_name']}
     except:
-        return {}
+        return {'template_name': ''}
 
 
 def getGraphVars(pattern, keys):
@@ -422,6 +426,7 @@ def getObjects(graph):
 
     Parameters:
         graph (MgvGraph): the graph.
+
     Return:
         dict: A complete dictionary representing the graph
               and all its elements.
@@ -450,7 +455,7 @@ def getObjects(graph):
             data['uuid'] = data['_id']
             graphObject['variables'].append(data)
         if data['code'] == 'Group':
-            data['uuid'] = g['_id']
+            data['uuid'] = data['_id']
             graphObject['groups'].append(data)
         if data['code'] == 'Node':
             data['uuid'] = data['_id']
