@@ -179,7 +179,8 @@ def getBatchScript(project_name, name=None, uuid=None):
     gt = gtyp[0]
 
     node_type = mgvApi.MgvBatchScript(uuid=gt['x']['uuid'], name=gt['x']['name'], users=gt['x']['users'],
-                              script=gt['x']['script'], pattern=gt['x']['pattern'], template=gt['x']['template'])
+                                      script=gt['x']['script'], pattern=gt['x']['pattern'],
+                                      template=gt['x']['template'], menu=gt['x']['menu'])
     return node_type
 
 
@@ -258,9 +259,6 @@ def getProject(projectName):
         if not versions_padding:
             versions_padding, versions_start = 3, 0
         script = gproj[0]['x']['script']
-        batchScripts = gproj[0]['x']['batchScripts']
-        if batchScripts:
-            batchScripts = json.loads(batchScripts)
         contexts = []
         gcon = neograph.run("MATCH (:Project {name:'%s'})-->(y:Context) RETURN y" % name).data()
         for gn in gcon:
@@ -278,6 +276,19 @@ def getProject(projectName):
             widevent = gn['y']['event']
             pyphud = mgvApi.MgvHud(uuid=widid, name=widname, script=widscript, event=widevent)
             huds.append(pyphud)
+        batchs = []
+        gwid = neograph.run("MATCH (:Project {name:'%s'})-->(y:BatchScript) RETURN y" % name).data()
+        for gn in gwid:
+            batid = gn['y']['uuid']
+            batname = gn['y']['name']
+            batmenu = gn['y']['menu']
+            batscript = gn['y']['script']
+            batusers = gn['y']['users']
+            batpattern = gn['y']['pattern']
+            battemplate = gn['y']['template']
+            pypbatch = mgvApi.MgvBatchScript(uuid=batid, name=batname, script=batscript, users=batusers,
+                                             pattern=batpattern, template=battemplate, menu=batmenu)
+            batchs.append(pypbatch)
         types = getTypes(name)
         patterns = []
         gpat = neograph.run("MATCH (:Project {name:'%s'})-->(y:Pattern) RETURN y" % name).data()
@@ -301,7 +312,7 @@ def getProject(projectName):
 
         patterns.sort(key=lambda x: x.order)
         p = mgvApi.MgvProject(uuid=pid, name=name, script=script, patterns=patterns, types=types, contexts=contexts,
-                              batchScripts=batchScripts, huds=huds, versions_padding=versions_padding,
+                              batchScripts=batchs, huds=huds, versions_padding=versions_padding,
                               versions_start=versions_start)
         return p
     return None
@@ -360,7 +371,7 @@ def getGraphInfo(pattern, keys):
     g = neograph.run(cmd)
     for gn in g:
         return {'code': 'Graph', 'uuid': gn['x.uuid'], 'template_name': gn['x.template_name']}
-    return {}
+    return {'template_name': ''}
 
 
 def getGraphVars(pattern, keys):
@@ -428,6 +439,7 @@ def getObjects(graph):
 
     Parameters:
         graph (MgvGraph): the graph.
+        
     Return:
         dict: A complete dictionary representing the graph
               and all its elements.
