@@ -3,7 +3,6 @@ import uuid
 import json
 import os
 import time
-import shutil
 
 USER = os.getenv('USER')
 if not USER:
@@ -85,6 +84,8 @@ def getFilePath(node, args=None):
 
     elif node.code == 'Graph':
         graph = node
+    elif node.code == 'Group':
+        graph = node.graph
     elif node.code == 'Node':
         graph = node.graph
     elif node.code == 'NodeVersion':
@@ -94,7 +95,7 @@ def getFilePath(node, args=None):
         if graph.code == 'NodeVersion':
             graph = graph.node.graph
 
-    if graph.path[-1] == '*template*':
+    if len(graph.path) and graph.path[-1] == '*template*':
         return os.path.join(os.path.dirname(projects_file_path), 'Templates', graph.pattern.project.name,
                             graph.pattern.name, graph.name + '.mgv')
     else:
@@ -306,7 +307,7 @@ def getBatchScript(project_name, name=None, uuid=None):
                 gt = t
                 break
 
-    node_type = mgvApi.MgvBatchScript(uuid=gt['uuid'], name=gt['name'], users=gt['users'],
+    node_type = mgvApi.MgvBatchScript(uuid=gt['uuid'], name=gt['name'], users=gt['users'], menu=gt['menu'],
                                       script=gt['script'], pattern=gt['pattern'], template=gt['template'])
 
     return node_type
@@ -393,14 +394,15 @@ def getProject(projectName):
         pypcontext = mgvApi.MgvContext(uuid=conid, name=conname, value=convalue)
         contexts.append(pypcontext)
     batchs = []
-    for gn in root[projectName]['BatchScripts']:
+    for gn in root[projectName]['batchScripts']:
         batid = gn['uuid']
         batname = gn['name']
+        batmenu = gn['menu'] if 'menu' in gn else ''
         batscript = gn['script']
         batusers = gn['users']
         batpattern = gn['pattern']
         battemplate = gn['template']
-        pypbatch = mgvApi.MgvBatchScript(uuid=batid, name=batname, script=batscript, users=batusers,
+        pypbatch = mgvApi.MgvBatchScript(uuid=batid, name=batname, script=batscript, users=batusers, menu=batmenu,
                                          pattern=batpattern, template=battemplate)
         batchs.append(pypbatch)
     huds = []
@@ -448,7 +450,7 @@ def getProjectNames():
     wait_lock_file(projects_file_path)
     with open(projects_file_path) as fid:
         root = json.load(fid)
-    return root.keys()
+    return list(root.keys())
 
 
 def getPatternGraphs(pattern, with_node_named=None, with_type_named=None):
@@ -468,8 +470,29 @@ def getPatternGraphs(pattern, with_node_named=None, with_type_named=None):
     with open(projects_file_path) as fid:
         root = json.load(fid)
     p = getByUuid(root, pattern.uuid)
-    g = [x.split(':') for x in p['graphs']]
-    return g
+    if with_node_named is None and with_type_named is None:
+        return [x.split(':') for x in p['graphs']]
+
+    result = []
+    for x in p['graphs']:
+        keys = x.split(':')
+        graph_file_path = os.path.join(pattern.convertPath(keys), pattern.convertGraphName(keys)) + '.mgv'
+        with open(graph_file_path) as fid:
+            root = json.load(fid)
+        found = False
+        if with_node_named:
+            for y in root['nodes']:
+                if with_node_named.lower() in y['name'].lower():
+                    found = True
+        if with_type_named:
+            if not with_node_named or found:
+                found = False
+                for y in root['nodes']:
+                    if y['typeName'] == with_type_named:
+                        found = True
+        if found:
+            result.append(x.split(':'))
+    return result
 
 
 def getGraphInfo(pattern, keys):
@@ -487,7 +510,7 @@ def getGraphInfo(pattern, keys):
     pat = [x for x in root[pattern.project.name]['patterns'] if x['name'] == pattern.name][0]
     gr = [x for x in pat['graphs'] if x == ':'.join(keys)]
     if not len(gr):
-        return {}
+        return {'template_name': ''}
     gr = gr[0]
     file_path = os.path.join(pattern.convertPath(keys), pattern.convertGraphName(keys) + '.mgv')
     wait_lock_file(file_path)
@@ -558,6 +581,7 @@ def getObjects(graph):
 
     Parameters:
         graph (MgvGraph): the graph.
+
     Return:
         dict: A complete dictionary representing the graph
               and all its elements.
@@ -625,7 +649,9 @@ def getNodeAttr(node, attr):
     with open(file_path) as fid:
         root = json.load(fid)
     t = getByUuid(root, uuid)
-    return t[attr]
+    if attr in t:
+        return t[attr]
+    return ''
 
 
 def createLink(nodeA, nodeB):
@@ -726,6 +752,7 @@ def createNode(father, code, **kwargs):
             kwargs['patterns'] = []
             kwargs['contexts'] = []
             kwargs['huds'] = []
+            kwargs['batchScripts'] = []
             root[kwargs['name']] = kwargs
         elif code == 'Pattern':
             kwargs['templates'] = []
@@ -737,6 +764,8 @@ def createNode(father, code, **kwargs):
             father_element['contexts'].append(kwargs)
         elif code == 'Hud':
             father_element['huds'].append(kwargs)
+        elif code == 'BatchScript':
+            father_element['batchScripts'].append(kwargs)
         elif code == 'Type':
             kwargs['versions'] = []
             kwargs['typeFiles'] = []
